@@ -177,8 +177,9 @@ class Wsdl(WsdlBase):
                 lambda group: group(
                     _("Update the Build"),
                     normal=('cl_builder_prepared_id',
+                            'cl_builder_binhost_stable_set',
                             'update.cl_update_binhost_recheck_set',
-                            'cl_builder_binhost_stable_set'),
+                            ),
                     expert=(
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
